C++ API Reference
=================

|

.. grid:: 2
   :gutter: 3

   .. grid-item-card:: Grids
       :link: grid
       :link-type: doc
       :text-align: center
       :img-top: ../_static/api_grid.svg

   .. grid-item-card:: Flow Routing
       :link: flow
       :link-type: doc
       :text-align: center
       :img-top: ../_static/api_graph.svg

   .. grid-item-card:: Eroders
       :link: eroder
       :link-type: doc
       :text-align: center
       :img-top: ../_static/api_eroder.svg

   .. grid-item-card:: Utilities
       :link: utilities
       :link-type: doc
       :text-align: center
       :img-top: ../_static/api_utils.svg


.. toctree::
   :hidden:
   :maxdepth: 1

   grid
   flow
   eroder
   utilities
